---
name: Feature request
about: Suggest an idea for this project
title: "🚀 "
labels: enhancement
assignees: ''

---

### User Story

*As a ...insert type of user... I'd like to ...insert desired feature or behavior...*

### What Happens Now

### Resolution Ideas

<!-- Describe what you'd like it to look like -->

### Priority

<!-- Use Low/Medium/High -->

### Level of Effort

<!-- Use tee-shirt-sizing: S/M/L/XL -->

### Project

<!-- Is there a funder or project associated with this feature?. -->

### Who should be involved?

Implementer:
Commenters:
Users:
Reviewers:

### Risk

*Will this potentially break anything?*

#### Tests

*What are relevant tests or what tests need to be created in order to determine that this issue is complete?*
